# POP-tools: Tools to support analysis of POP2-CESM model solutions with xarray

| CI          | [![GitHub Workflow Status][github-ci-badge]][github-ci-link] [![Code Coverage Status][codecov-badge]][codecov-link] |
| :---------- | :-----------------------------------------------------------------------------------------------------------------: |
| **Docs**    |                                   [![Documentation Status][rtd-badge]][rtd-link]                                    |
| **Package** |                        [![Conda][conda-badge]][conda-link] [![PyPI][pypi-badge]][pypi-link]                         |
| **License** |                                       [![License][license-badge]][repo-link]                                        |

## Installation

pop-tools can be installed from PyPI with pip:

```bash
python -m pip install pop-tools
```

pop-tools is also available from conda-forge for conda installations:

```bash
conda install -c conda-forge pop-tools
```

See [documentation](https://pop-tools.readthedocs.io) for more information.

[github-ci-badge]: https://img.shields.io/github/workflow/status/NCAR/pop-tools/CI?label=CI&logo=github&style=for-the-badge
[github-ci-link]: https://github.com/NCAR/pop-tools/actions?query=workflow%3ACI
[codecov-badge]: https://img.shields.io/codecov/c/github/NCAR/pop-tools.svg?logo=codecov&style=for-the-badge
[codecov-link]: https://codecov.io/gh/NCAR/pop-tools
[rtd-badge]: https://img.shields.io/readthedocs/pop-tools/latest.svg?style=for-the-badge
[rtd-link]: https://pop-tools.readthedocs.io/en/latest/?badge=latest
[pypi-badge]: https://img.shields.io/pypi/v/pop-tools?logo=pypi&style=for-the-badge
[pypi-link]: https://pypi.org/project/pop-tools
[conda-badge]: https://img.shields.io/conda/vn/conda-forge/pop-tools?logo=anaconda&style=for-the-badge
[conda-link]: https://anaconda.org/conda-forge/pop-tools
[license-badge]: https://img.shields.io/github/license/NCAR/pop-tools?style=for-the-badge
[repo-link]: https://github.com/NCAR/pop-tools
